VERSION 5.00
Begin VB.UserControl Clock 
   AutoRedraw      =   -1  'True
   ClientHeight    =   330
   ClientLeft      =   0
   ClientTop       =   0
   ClientWidth     =   1890
   ScaleHeight     =   22
   ScaleMode       =   3  'Pixel
   ScaleWidth      =   126
End
Attribute VB_Name = "Clock"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
' *********************************************************************
'  Copyright 1998 Karl E. Peterson, All Rights Reserved
' *********************************************************************
'  You are free to use this code within your own applications, but you
'  are expressly forbidden from selling or otherwise distributing this
'  source code without prior written consent.
' *********************************************************************
Option Explicit

Private Const defBackColor = vbButtonFace
Private Const defForeColor = vbWindowText
Private Const defEnabled = True

Private m_Enabled As Boolean
Private m_INotify As ISharedTimer

Event Click()
Event MouseDown(Button As Integer, Shift As Integer, x As Single, y As Single)
Event MouseMove(Button As Integer, Shift As Integer, x As Single, y As Single)
Event MouseUp(Button As Integer, Shift As Integer, x As Single, y As Single)

Implements ISharedTimer

' ****************************************************
'  Initialization and Termination
' ****************************************************
Private Sub UserControl_Initialize()
   '
   ' Do main initialization in ReadProperties.
   ' Store reference to secondary interface here.
   '
   Set m_INotify = Me
End Sub

Private Sub UserControl_Terminate()
   '
   ' Unregister control instance.
   '
   If m_Enabled Then
      Call UnRegisterInstance(Me)
   End If
End Sub

Private Sub UserControl_InitProperties()
   With UserControl
      .AutoRedraw = True
      .BackColor = defBackColor
      Set .Font = Ambient.Font
      .ForeColor = defForeColor
      .ScaleMode = vbPixels
   End With
End Sub

Private Sub UserControl_ReadProperties(PropBag As PropertyBag)
   With UserControl
      .AutoRedraw = True
      .BackColor = PropBag.ReadProperty("BackColor", defBackColor)
      Set .Font = PropBag.ReadProperty("Font", Ambient.Font)
      .ForeColor = PropBag.ReadProperty("ForeColor", defForeColor)
      .ScaleMode = vbPixels
      m_Enabled = PropBag.ReadProperty("Enabled", defEnabled)
   End With
   '
   ' Register control instance.
   '
   If m_Enabled Then
      Call RegisterInstance(Me)
   End If
End Sub

Private Sub UserControl_WriteProperties(PropBag As PropertyBag)
   With UserControl
      PropBag.WriteProperty "BackColor", .BackColor, defBackColor
      PropBag.WriteProperty "Font", .Font, Ambient.Font
      PropBag.WriteProperty "ForeColor", .ForeColor, defForeColor
      PropBag.WriteProperty "Enabled", m_Enabled, defEnabled
   End With
End Sub

' ****************************************************
'  UserControl Events
' ****************************************************
Private Sub UserControl_Click()
   RaiseEvent Click
End Sub

Private Sub UserControl_MouseDown(Button As Integer, Shift As Integer, x As Single, y As Single)
   RaiseEvent MouseDown(Button, Shift, _
      CLng(ScaleX(x, vbPixels, vbContainerSize)), _
      CLng(ScaleY(y, vbPixels, vbContainerSize)))
End Sub

Private Sub UserControl_MouseMove(Button As Integer, Shift As Integer, x As Single, y As Single)
   RaiseEvent MouseMove(Button, Shift, _
      CLng(ScaleX(x, vbPixels, vbContainerSize)), _
      CLng(ScaleY(y, vbPixels, vbContainerSize)))
End Sub

Private Sub UserControl_MouseUp(Button As Integer, Shift As Integer, x As Single, y As Single)
   RaiseEvent MouseUp(Button, Shift, _
      CLng(ScaleX(x, vbPixels, vbContainerSize)), _
      CLng(ScaleY(y, vbPixels, vbContainerSize)))
End Sub

Private Sub UserControl_Paint()
   Call Me.Refresh
End Sub

Private Sub UserControl_Resize()
   Call Me.Refresh
End Sub

' ****************************************************
'  Public Properties
' ****************************************************
Public Property Let BackColor(ByVal NewVal As OLE_COLOR)
   UserControl.BackColor = NewVal
   PropertyChanged "BackColor"
   Me.Refresh
End Property

Public Property Get BackColor() As OLE_COLOR
   BackColor = UserControl.BackColor
End Property

Public Property Let Enabled(ByVal NewVal As Boolean)
   If NewVal <> m_Enabled Then
      m_Enabled = NewVal
      PropertyChanged "Enabled"
      If m_Enabled Then
         Call RegisterInstance(m_INotify)
      Else
         Call UnRegisterInstance(m_INotify)
      End If
   End If
End Property

Public Property Get Enabled() As Boolean
   Enabled = m_Enabled
End Property

Public Property Set Font(ByVal NewFont As Font)
   If Not (NewFont Is Nothing) Then
      Set UserControl.Font = NewFont
      PropertyChanged "Font"
      Me.Refresh
   End If
End Property

Public Property Get Font() As Font
   Set Font = UserControl.Font
End Property

Public Property Let ForeColor(ByVal NewVal As OLE_COLOR)
   UserControl.ForeColor = NewVal
   PropertyChanged "ForeColor"
   Me.Refresh
End Property

Public Property Get ForeColor() As OLE_COLOR
   ForeColor = UserControl.ForeColor
End Property

' ****************************************************
'  Public Methods
' ****************************************************
Public Static Sub Refresh(Optional ByVal ShowColons As Boolean = True)
   Dim disp As String
   Dim i As Long
   '
   ' Format time string.
   '
   disp = Format$(Now, "long time")
   '
   ' Update display.
   '
   With UserControl
      .Cls
      .CurrentX = (.ScaleWidth - .TextWidth(disp)) \ 2
      .CurrentY = (.ScaleHeight \ 2) - (.TextHeight(disp) \ 2)
      If ShowColons = False Then
         For i = 1 To Len(disp)
            If InStr(i, disp, ":") = i Then
               Mid$(disp, i, 1) = " "
            End If
         Next i
      End If
      UserControl.Print disp
      UserControl.Line (0, 0)-(.ScaleWidth - 1, .ScaleHeight - 1), , B
   End With
End Sub

' ****************************************************
'  Friend Methods -- Exposed to identify and
'                    and communicating with
'                    each control instance.
' ****************************************************
Friend Sub Timer(ByVal ShowColons As Boolean)
   Me.Refresh ShowColons
End Sub

Friend Property Get AmbientUserMode() As Boolean
   AmbientUserMode = Ambient.UserMode
End Property

' ****************************************************
'  Implemented Methods
' ****************************************************
Private Sub ISharedTimer_Timer(ByVal ShowColons As Boolean)
   Me.Refresh ShowColons
End Sub

Private Function ISharedTimer_AmbientUserMode() As Boolean
   ISharedTimer_AmbientUserMode = Ambient.UserMode
End Function


